@@ -790,6 +790,18 @@ basep_widget_focus_in_event (GtkWidget     *widget,
 	if (basep->state == BASEP_AUTO_HIDDEN)
 		basep_widget_autoshow (basep);
 
+#if 0
+        /* FIXME: When we have focus and hit ctrl-alt-tab with
+         *        Metacity, it does a grab and we a FocusChange
+         *        event because gdk doesn't ignore NotifyGrab
+         *        FocusChange events. See #ifdefed out case
+         *        in gdkevents-x11.c.
+         */
+        else if (basep->state == BASEP_HIDDEN_LEFT ||
+                 basep->state == BASEP_HIDDEN_RIGHT)
+                basep_widget_explicit_show (basep);
+#endif
+
 	return GTK_WIDGET_CLASS (basep_widget_parent_class)->focus_in_event (widget, event);
 }
 
@@ -1457,12 +1469,9 @@ basep_update_frame (BasePWidget *basep)
 }
 
 static void
-basep_back_change (PanelWidget *panel,
-		   PanelBackType type,
-		   char *pixmap,
-		   GdkColor *color,
-		   BasePWidget *basep)
+basep_back_change (PanelWidget *panel, gpointer data)
 {
+	BasePWidget *basep = BASEP_WIDGET (data);
 	basep_update_frame (basep);
 
 	panel_set_frame_colors (panel,
@@ -1474,10 +1483,9 @@ basep_back_change (PanelWidget *panel,
 }
 
 static void
-basep_orient_change (PanelWidget *panel,
-		     GtkOrientation orient,
-		     BasePWidget *basep)
+basep_orient_change (PanelWidget *panel, gpointer data)
 {
+	BasePWidget *basep = BASEP_WIDGET (data);
 	setup_hidebuttons (basep);
 }
 
