@@ -92,8 +92,6 @@ int on_toplevel_key_press_event (GtkWidget *widget, GdkEventKey *key);
 
 /* some local prototypes */
 static gchar * add_file_to_path (const gchar *path);
-gint shot_delay_callback (gpointer data);
-
 
 /* helper functions */
 /* This code is copied from gdk-pixbuf-HEAD.  It does no memory management and
@@ -203,8 +201,10 @@ nibble_on_file (const char *file)
 			 GTK_BUTTONS_YES_NO,
 			 _("File %s already exists. Overwrite?"),
 			 file);
-		if (gtk_dialog_run (GTK_DIALOG (dialog)) != GTK_RESPONSE_YES)
+		if (gtk_dialog_run (GTK_DIALOG (dialog)) != GTK_RESPONSE_YES) {
+			gtk_widget_destroy (dialog);
 			return NULL;
+		}
 	}
 	fp = fopen (file, "w");
 	if (fp == NULL) {
@@ -218,6 +218,7 @@ nibble_on_file (const char *file)
 			   "Please check your permissions of "
 			   "the parent directory"), file);
 		gtk_dialog_run (GTK_DIALOG (dialog));
+		gtk_widget_destroy (dialog);
 		return NULL;
 	}
 	return fp;
@@ -242,6 +243,7 @@ save_to_file (FILE *fp, const gchar *file, gboolean gui_errors)
 				 GTK_BUTTONS_OK,
 				 "%s", error);
 			gtk_dialog_run (GTK_DIALOG (dialog));
+			gtk_widget_destroy (dialog);
 		}
 		fclose (fp);
 		unlink (file);
@@ -545,18 +547,23 @@ print_pixbuf (void)
 static gchar *
 add_file_to_path (const gchar *path)
 {
-	gchar *retval;
-	gint i = 1;
+	char *retval;
+	char *tmp;
+	int   i = 1;
 
 	if (class_name) {
 		/* translators: this is the file that gets made up with the screenshot if a specific window is taken */
-		retval = g_strdup_printf (_("%s%cScreenshot-%s.png"), path,
-					  G_DIR_SEPARATOR, class_name);
+		tmp = g_strdup_printf (_("%s%cScreenshot-%s.png"), path,
+				       G_DIR_SEPARATOR, class_name);
+		retval = g_filename_from_utf8 (tmp, -1, NULL, NULL, NULL);
+		g_free (tmp);
 	}
 	else {
 		/* translators: this is the file that gets made up with the screenshot if the entire screen is taken */
-		retval = g_strdup_printf (_("%s%cScreenshot.png"), path,
-					  G_DIR_SEPARATOR);
+		tmp = g_strdup_printf (_("%s%cScreenshot.png"), path,
+				       G_DIR_SEPARATOR);
+		retval = g_filename_from_utf8 (tmp, -1, NULL, NULL, NULL);
+		g_free (tmp);
 	}
 	
 	do {
@@ -570,13 +577,17 @@ add_file_to_path (const gchar *path)
 
 		if (class_name) {
 			/* translators: this is the file that gets made up with the screenshot if a specific window is taken */
-			retval = g_strdup_printf (_("%s%cScreenshot-%s-%d.png"), path,
-						  G_DIR_SEPARATOR, class_name, i);
+			tmp = g_strdup_printf (_("%s%cScreenshot-%s-%d.png"), path,
+					       G_DIR_SEPARATOR, class_name, i);
+			retval = g_filename_from_utf8 (tmp, -1, NULL, NULL, NULL);
+			g_free (tmp);
 		}
 		else {
 			/* translators: this is the file that gets made up with the screenshot if the entire screen is taken */
-			retval = g_strdup_printf (_("%s%cScreenshot-%d.png"), path,
-						  G_DIR_SEPARATOR, i);
+			tmp = g_strdup_printf (_("%s%cScreenshot-%d.png"), path,
+					       G_DIR_SEPARATOR, i);
+			retval = g_filename_from_utf8 (tmp, -1, NULL, NULL, NULL);
+			g_free (tmp);
 		}
 		
 		i++;
@@ -706,6 +717,7 @@ gimme_file (const char *filename)
 				   "Please check your permissions of "
 				   "the parent directory"), filename);
 			gtk_dialog_run (GTK_DIALOG (dialog));
+			gtk_widget_destroy (dialog);
 			close (infd);
 			return FALSE;
 		}
@@ -724,6 +736,7 @@ gimme_file (const char *filename)
 					 _("Not enough room to write file %s"),
 					 filename);
 				gtk_dialog_run (GTK_DIALOG (dialog));
+				gtk_widget_destroy (dialog);
 				return FALSE;
 			}
 		}
@@ -1005,17 +1018,6 @@ drag_begin (GtkWidget *widget, GdkDragContext *context)
 	start_temporary ();
 }
 
-gint
-shot_delay_callback (gpointer data)
-{
-	gint *seconds_left = (gint *) data;
-
-	(*seconds_left)--;
-	if (!*seconds_left)
-		gtk_main_quit ();
-	return *seconds_left;
-}
-
 /* main */
 int
 main (int argc, char *argv[])
@@ -1025,7 +1027,7 @@ main (int argc, char *argv[])
 	GConfClient *gconf_client;
 	GnomeClient *client;
 	struct stat s;
-	gchar *file;
+	gchar *file, *window_icon;
 	gboolean window = FALSE;
 	gint width, height; 
 	guint delay = 0;
@@ -1052,8 +1054,7 @@ main (int argc, char *argv[])
 	gnome_client_set_restart_style (client, GNOME_RESTART_NEVER);
 	
 	if (delay > 0) {
-		gtk_timeout_add (1000, shot_delay_callback, &delay);
-		gtk_main ();
+		sleep (delay);	
 	}
 	
 	if (window)
@@ -1078,6 +1079,7 @@ main (int argc, char *argv[])
 			 _("Glade file for the screenshot program is missing.\n"
 			   "Please check your installation of gnome-panel"));
 		gtk_dialog_run (GTK_DIALOG (dialog));
+		gtk_widget_destroy (dialog);
 		exit (1);
 	}
 	glade_xml_signal_autoconnect (xml);
@@ -1100,6 +1102,7 @@ main (int argc, char *argv[])
 			_("Unable to take a screenshot of "
 			   "the current desktop."));
 		gtk_dialog_run (GTK_DIALOG (dialog));
+		gtk_widget_destroy (dialog);
 		exit (1);
 	}
 
@@ -1114,6 +1117,14 @@ main (int argc, char *argv[])
 	preview = glade_xml_get_widget (xml, "preview");
 	save_entry = glade_xml_get_widget (xml, "save_entry");
 
+	window_icon = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_PIXMAP, 
+						 "gnome-screenshot.png", TRUE, NULL);
+	if (window_icon) {
+		gnome_window_icon_set_from_file (GTK_WINDOW (toplevel), window_icon);
+		g_free (window_icon);
+	}
+
+	
 	gtk_window_set_default_size (GTK_WINDOW (toplevel), width * 2, -1);
 	gtk_widget_set_size_request (preview, width, height);
 	gtk_aspect_frame_set (GTK_ASPECT_FRAME (frame), 0.5, 0.5,
