@@ -22,6 +22,12 @@ void       panel_menu_position    (GtkMenu  *menu,
 				   gboolean *push_in,
 				   gpointer  data);
 
+void       menu_item_menu_position   (GtkMenu  *menu,
+				      gint     *x,
+				      gint     *y,
+				      gboolean *push_in,
+				      gpointer  data);
+
 char *     get_real_menu_path      (const char *arguments,
                                     gboolean main_menu);
 char *     get_pixmap              (const char *menudir,
@@ -29,6 +35,10 @@ char *     get_pixmap              (const char *menudir,
 
 GtkWidget *add_menu_separator     (GtkWidget *menu);
 
+GtkWidget * pixmap_menu_item_new (const char *text, const char *try_file, gboolean force_image);
+void menu_util_screenshot (GtkWidget *widget, gpointer data);
+void menu_util_search (GtkWidget *widget, gpointer data);
+
 int        get_default_menu_flags (void);
 gboolean   got_kde_menus (void);
 gboolean   got_distro_menus (void);
